==> ggstatsplot_0.0.10.tar.gz: ggstatsplot/R/global_vars.R <==
# defining global variables and functions to appease R CMD Check

utils::globalVariables(
  names = c(
    ".",
    "conf.level",
    "nboot",
    "U",
    "V",
    "Z",
    "chi",
    "counts",
    "df",
    "df1",
    "df2",
    "desc",
    "do",
    "effsize",
    "estimate",
    "eta",
    "omega",
    "etasq",
    "omegasq",
    "perc",
    "cramer",
    "cramer_ci",
    "pvalue",
    "r",
    "rho",
    "xi",
    "y",
    "z_value",
    "italic",
    "rsubtitle",
    "stats_subtitle",
    "chi_subtitle",
    "proptest_subtitle",
    "LL",
    "UL",
    "outlier",
    "outlier.label",
    "proptest_subtitle",
    "significance",
    "..count..",
    "..density..",
    "dnorm",
    "mean",
    "median",
    "sd",
    "bf",
    "bf_error",
    "bf_prior",
    "Df",
    "F value",
    "F.value",
    "LL",
    "Pr(>F)",
    "UL",
    "complete",
    "data",
    "df1",
    "df2",
    "effect",
    "effsize",
    "formula",
    "hist",
    "median",
    "p0",
    "p100",
    "p50",
    "p25",
    "p75",
    "sd",
    "type",
    "Chi-squared",
    "df",
    "p-value",
    "chi_sq",
    "significance",
    "F-value",
    "V2",
    "V3",
    "V4",
    "V5",
    "conf",
    "AIC",
    "BIC",
    "R",
    "adj.r.squared",
    "p.value",
    "term",
    "label",
    "loglik",
    "Pr(>|t|)",
    "coef",
    "conf.high",
    "conf.low",
    "mean.high.conf",
    "mean.low.conf",
    "rowid",
    "Cramer's V",
    "df[chiSq]",
    "p[chiSq]",
    "value[chiSq]",
    "condition_n_label",
    "total_n",
    "robust",
    "partial.etasq",
    "partial.omegasq",
    "stratum",
    "coefficient_type",
    "mean.y",
    "n.y",
    "sd.y",
    "se.y",
    "std.error",
    "pair",
    "bold",
    "x...internal",
    "y...internal",
    "or",
    "atop",
    "top.text",
    "bottom.text",
    "code",
    "time",
    "t-value",
    "Group",
    "Group1",
    "group1",
    "group2",
    "Group..1",
    "Group..2",
    "Group...1",
    "Group...2",
    "ci.lower",
    "ci.upper",
    "comparison",
    "p",
    "p1",
    "p2",
    "high.conf",
    "i1",
    "i2",
    "key",
    "low.conf",
    "mean.difference",
    "p.crit",
    "sep",
    "value",
    "var",
    "label2",
    "p.value.label",
    "sampling.plan",
    "displaystyle",
    "textstyle",
    "a",
    "x",
    "bf01",
    "bf10",
    "log_10_bf01",
    "log_10_bf10",
    "log_e_bf01",
    "log_e_bf10",
    "2.5 %",
    "97.5 %",
    "group",
    "name",
    "se",
    "zvalue",
    "isanoutlier",
    "Cramer.V",
    "t.value",
    "ci.lb",
    "ci.ub",
    "pval",
    "zval",
    "statistic.z",
    "variable",
    "method",
    "N",
    "compare_list",
    "I2",
    "Q",
    "tau",
    "tau2",
    "id",
    "coef.type"
  ),
  package = "ggstatsplot",
  add = FALSE
)

==> ggstatsplot_0.0.11.tar.gz: ggstatsplot/R/global_vars.R <==
# defining global variables and functions to appease R CMD Check

utils::globalVariables(
  names = c(
    ".",
    "conf.level",
    "nboot",
    "U",
    "V",
    "Z",
    "chi",
    "counts",
    "df",
    "df1",
    "df2",
    "desc",
    "do",
    "effsize",
    "estimate",
    "eta",
    "omega",
    "etasq",
    "omegasq",
    "perc",
    "cramer",
    "cramer_ci",
    "pvalue",
    "r",
    "rho",
    "xi",
    "y",
    "z_value",
    "italic",
    "rsubtitle",
    "stats_subtitle",
    "chi_subtitle",
    "proptest_subtitle",
    "LL",
    "UL",
    "outlier",
    "outlier.label",
    "proptest_subtitle",
    "significance",
    "..count..",
    "..density..",
    "dnorm",
    "mean",
    "median",
    "sd",
    "bf",
    "bf_error",
    "bf_prior",
    "Df",
    "F value",
    "F.value",
    "LL",
    "Pr(>F)",
    "UL",
    "complete",
    "data",
    "df1",
    "df2",
    "effect",
    "effsize",
    "formula",
    "hist",
    "median",
    "p0",
    "p100",
    "p50",
    "p25",
    "p75",
    "sd",
    "type",
    "Chi-squared",
    "df",
    "p-value",
    "chi_sq",
    "significance",
    "F-value",
    "V2",
    "V3",
    "V4",
    "V5",
    "conf",
    "AIC",
    "BIC",
    "R",
    "adj.r.squared",
    "p.value",
    "term",
    "label",
    "loglik",
    "Pr(>|t|)",
    "coef",
    "conf.high",
    "conf.low",
    "mean.high.conf",
    "mean.low.conf",
    "rowid",
    "Cramer's V",
    "df[chiSq]",
    "p[chiSq]",
    "value[chiSq]",
    "condition_n_label",
    "total_n",
    "robust",
    "partial.etasq",
    "partial.omegasq",
    "stratum",
    "coefficient_type",
    "mean.y",
    "n.y",
    "sd.y",
    "se.y",
    "std.error",
    "pair",
    "bold",
    "x...internal",
    "y...internal",
    "or",
    "atop",
    "top.text",
    "bottom.text",
    "code",
    "time",
    "t-value",
    "Group",
    "Group1",
    "group1",
    "group2",
    "Group..1",
    "Group..2",
    "Group...1",
    "Group...2",
    "ci.lower",
    "ci.upper",
    "comparison",
    "p",
    "p1",
    "p2",
    "high.conf",
    "i1",
    "i2",
    "key",
    "low.conf",
    "mean.difference",
    "p.crit",
    "sep",
    "value",
    "var",
    "label2",
    "p.value.label",
    "sampling.plan",
    "displaystyle",
    "textstyle",
    "a",
    "x",
    "bf01",
    "bf10",
    "log_10_bf01",
    "log_10_bf10",
    "log_e_bf01",
    "log_e_bf10",
    "2.5 %",
    "97.5 %",
    "group",
    "name",
    "se",
    "zvalue",
    "isanoutlier",
    "Cramer.V",
    "t.value",
    "ci.lb",
    "ci.ub",
    "pval",
    "zval",
    "statistic.z",
    "variable",
    "method",
    "N",
    "compare_list",
    "I2",
    "Q",
    "tau",
    "tau2",
    "id",
    "coef.type",
    "Value",
    "Statistic",
    "d.pmean",
    "d.pmean.LB",
    "d.pmean.UB",
    "Cramer V",
    "lwr.ci",
    "upr.ci",
    "lower.ci",
    "upper.ci"
  ),
  package = "ggstatsplot",
  add = FALSE
)
